@@ -45,13 +45,13 @@
 #include "gtksheet-marshal.h"
 #include "gtksheettypebuiltins.h"
 
-#undef GTK_SHEET_COL_DEBUG
+#define GTK_SHEET_COL_DEBUG 0
 
 #ifdef DEBUG
-#define GTK_SHEET_COL_DEBUG 1  /* define to activate debug output */
+#define GTK_SHEET_COL_DEBUG 0  /* 1 = activate debug output */
 #endif
 
-#ifdef GTK_SHEET_COL_DEBUG
+#if GTK_SHEET_COL_DEBUG > 0
 #   define GTK_SHEET_COL_DEBUG_BUILDER   0
 #   define GTK_SHEET_COL_DEBUG_DRAW  0
 #   define GTK_SHEET_COL_DEBUG_PROPERTIES  0
@@ -143,6 +143,7 @@ _column_button_press_handler(
             button_event->x, button_event->y,
             &button_event->x, &button_event->y);
 
+        g_object_ref(sheet->column_title_window);  /* 322223 */
         button_event->window = sheet->column_title_window;
 
         gboolean retval;
@@ -1028,6 +1029,8 @@ _gtk_sheet_column_realize(GtkSheetColumn *colobj, GtkSheet *sheet)
         
         gtk_widget_set_realized(GTK_WIDGET(colobj), TRUE);
 
+        _gtk_sheet_column_check_windows(colobj, sheet);
+
         if (colobj->col_button)
         {
             DEBUG_WIDGET_SET_PARENT_WIN(
